import { system, world } from '@minecraft/server'

const harvestable = [
    { block: "minecraft:wheat", level: 7, state: "growth" },
    { block: "minecraft:pumpkin_stem", level: 7, state: "growth" },
    { block: "minecraft:melon_stem", level: 7, state: "growth" },
    { block: "minecraft:beetroot", level: 7, state: "growth" },
    { block: "minecraft:potatoes", level: 7, state: "growth" },
    { block: "minecraft:carrots", level: 7, state: "growth" },
    { block: "minecraft:sweet_berry_bush", level: 3, state: "growth" },
    { block: "minecraft:pitcher_crop", level: 4, state: "growth" },
    { block: "minecraft:nether_wart", level: 3, state: "age" },
    { block: "minecraft:cocoa", level: 2, state: "age" },
]
function isHarvestable(block) {
    // Verificamos si el bloque existe y tiene un typeId antes de hacer la comparación
    if (block && block.typeId) {
        return harvestable.find((cultivo) => cultivo.block === block.typeId);
    }
    return null; // Devuelve null si el bloque no es válido o no está en la lista
}

// función para hacer crecer el cultivo
function growCrop(block, cultivo, player, coords) {
    let states = block.permutation.getState(cultivo.state);
    if (states < cultivo.level) {
        block.setPermutation(block.permutation.withState(cultivo.state, states + 1));
        world.getDimension(player.dimension.id).spawnParticle('minecraft:crop_growth_emitter', coords)
    }
}
system.runInterval(() => {
    const players = world.getAllPlayers();
    players.forEach((player) => {
        const { x, y, z } = player.location;

        if (!player.isSneaking) {
            player.removeTag("twerk");
        } else if (!player.hasTag("twerk")) {
            player.addTag("twerk");

            for (let i = -2; i <= 2; i++) {
                for (let j = -2; j <= 2; j++) {
                    for (let k = -2; k <= 2; k++) {
                        const coords = { x: Math.floor(x) + i, y: Math.floor(y) + j, z: Math.floor(z) + k };
                        const block = player.dimension.getBlock(coords);
                        
                        const cultivo = isHarvestable(block);
                        if (cultivo) {
                            growCrop(block, cultivo, player, coords);
                        }
                    }
                }
            }
        }

        if (player.hasTag("twerk_text")) player.onScreenDisplay.setActionBar("§aBring rhythm to your crops with a good twerk!");
    });
});
system.runInterval(() => {
    const players = world.getAllPlayers();
    players.forEach((player) => {
        const { x, y, z } = player.location;
        const block = player.dimension.getBlock({ x, y: y+1, z });

        const cultivo = isHarvestable(block);
        if (cultivo) {
            let states = block.permutation.getState(cultivo.state);
            if (states < cultivo.level) {
                player.addTag("twerk_text");
            } 
        } else {
            player.removeTag("twerk_text");
        }
    });
});
